==> python-dateparser-0.7.6-1-any.pkg.tar.xz: usr/lib/python3.8/site-packages/dateparser/data/date_translation_data/ky.py <==
# -*- coding: utf-8 -*-
info = {
    "name": "ky",
    "date_order": "DMY",
    "january": [
        "январь",
        "янв"
    ],
    "february": [
        "февраль",
        "фев"
    ],
    "march": [
        "март",
        "мар"
    ],
    "april": [
        "апрель",
        "апр"
    ],
    "may": [
        "май"
    ],
    "june": [
        "июнь",
        "июн"
    ],
    "july": [
        "июль",
        "июл"
    ],
    "august": [
        "август",
        "авг"
    ],
    "september": [
        "сентябрь",
        "сен"
    ],
    "october": [
        "октябрь",
        "окт"
    ],
    "november": [
        "ноябрь",
        "ноя"
    ],
    "december": [
        "декабрь",
        "дек"
    ],
    "monday": [
        "дүйшөмбү",
        "дүй"
    ],
    "tuesday": [
        "шейшемби",
        "шейш"
    ],
    "wednesday": [
        "шаршемби",
        "шарш"
    ],
    "thursday": [
        "бейшемби",
        "бейш"
    ],
    "friday": [
        "жума"
    ],
    "saturday": [
        "ишемби",
        "ишм"
    ],
    "sunday": [
        "жекшемби",
        "жек"
    ],
    "am": [
        "таңкы",
        "тң"
    ],
    "pm": [
        "түштөн кийинки",
        "тк"
    ],
    "year": [
        "жыл",
        "ж"
    ],
    "month": [
        "ай"
    ],
    "week": [
        "апта",
        "апт"
    ],
    "day": [
        "күн"
    ],
    "hour": [
        "саат",
        "ст"
    ],
    "minute": [
        "мүнөт",
        "мүн",
        "м"
    ],
    "second": [
        "секунд",
        "сек"
    ],
    "relative-type": {
        "1 year ago": [
            "былтыр"
        ],
        "0 year ago": [
            "быйыл"
        ],
        "in 1 year": [
            "эмдиги жылы"
        ],
        "1 month ago": [
            "өткөн айда"
        ],
        "0 month ago": [
            "бул айда"
        ],
        "in 1 month": [
            "эмдиги айда"
        ],
        "1 week ago": [
            "өткөн аптада",
            "өткөн апт"
        ],
        "0 week ago": [
            "ушул аптада",
            "ушул апт"
        ],
        "in 1 week": [
            "келерки аптада",
            "келерки апт"
        ],
        "1 day ago": [
            "кечээ"
        ],
        "0 day ago": [
            "бүгүн"
        ],
        "in 1 day": [
            "эртеӊ"
        ],
        "0 hour ago": [
            "ушул саатта"
        ],
        "0 minute ago": [
            "ушул мүнөттө"
        ],
        "0 second ago": [
            "азыр"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "(\\d+) жылдан кийин",
            "(\\d+) жыл кийин"
        ],
        "\\1 year ago": [
            "(\\d+) жыл мурун"
        ],
        "in \\1 month": [
            "(\\d+) айдан кийин",
            "(\\d+) айд кийин",
            "(\\d+) айд кийн"
        ],
        "\\1 month ago": [
            "(\\d+) ай мурун",
            "(\\d+) ай мурн"
        ],
        "in \\1 week": [
            "(\\d+) аптадан кийин",
            "(\\d+) апт кийин"
        ],
        "\\1 week ago": [
            "(\\d+) апта мурун",
            "(\\d+) апт мурун"
        ],
        "in \\1 day": [
            "(\\d+) күндөн кийин",
            "(\\d+) күн кийин"
        ],
        "\\1 day ago": [
            "(\\d+) күн мурун"
        ],
        "in \\1 hour": [
            "(\\d+) сааттан кийин",
            "(\\d+) саат кийин",
            "(\\d+) с кийн"
        ],
        "\\1 hour ago": [
            "(\\d+) саат мурун",
            "(\\d+) с мурн"
        ],
        "in \\1 minute": [
            "(\\d+) мүнөттөн кийин",
            "(\\d+) мүн кийин",
            "(\\d+) мүн кийн"
        ],
        "\\1 minute ago": [
            "(\\d+) мүнөт мурун",
            "(\\d+) мүн мурун",
            "(\\d+) мүн мурн"
        ],
        "in \\1 second": [
            "(\\d+) секунддан кийин",
            "(\\d+) сек кийин",
            "(\\d+) сек кийн"
        ],
        "\\1 second ago": [
            "(\\d+) секунд мурун",
            "(\\d+) сек мурун",
            "(\\d+) сек мурн"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}

==> python-dateparser-1.1.1-1-any.pkg.tar.xz: usr/lib/python3.10/site-packages/dateparser/data/date_translation_data/ky.py <==
info = {
    "name": "ky",
    "date_order": "DMY",
    "january": [
        "янв",
        "январь"
    ],
    "february": [
        "фев",
        "февраль"
    ],
    "march": [
        "мар",
        "март"
    ],
    "april": [
        "апр",
        "апрель"
    ],
    "may": [
        "май"
    ],
    "june": [
        "июн",
        "июнь"
    ],
    "july": [
        "июл",
        "июль"
    ],
    "august": [
        "авг",
        "август"
    ],
    "september": [
        "сен",
        "сентябрь"
    ],
    "october": [
        "окт",
        "октябрь"
    ],
    "november": [
        "ноя",
        "ноябрь"
    ],
    "december": [
        "дек",
        "декабрь"
    ],
    "monday": [
        "дүй",
        "дүйшөмбү"
    ],
    "tuesday": [
        "шейш",
        "шейшемби"
    ],
    "wednesday": [
        "шарш",
        "шаршемби"
    ],
    "thursday": [
        "бейш",
        "бейшемби"
    ],
    "friday": [
        "жума"
    ],
    "saturday": [
        "ишемби",
        "ишм"
    ],
    "sunday": [
        "жек",
        "жекшемби"
    ],
    "am": [
        "таңкы",
        "тң"
    ],
    "pm": [
        "тк",
        "түштөн кийинки"
    ],
    "year": [
        "ж",
        "жыл"
    ],
    "month": [
        "ай"
    ],
    "week": [
        "апт",
        "апта"
    ],
    "day": [
        "күн"
    ],
    "hour": [
        "саат",
        "ст"
    ],
    "minute": [
        "м",
        "мүн",
        "мүнөт"
    ],
    "second": [
        "сек",
        "секунд"
    ],
    "relative-type": {
        "0 day ago": [
            "бүгүн"
        ],
        "0 hour ago": [
            "ушул саатта"
        ],
        "0 minute ago": [
            "ушул мүнөттө"
        ],
        "0 month ago": [
            "бул айда"
        ],
        "0 second ago": [
            "азыр"
        ],
        "0 week ago": [
            "ушул апт",
            "ушул аптада"
        ],
        "0 year ago": [
            "быйыл"
        ],
        "1 day ago": [
            "кечээ"
        ],
        "1 month ago": [
            "өткөн айда"
        ],
        "1 week ago": [
            "өткөн апт",
            "өткөн аптада"
        ],
        "1 year ago": [
            "былтыр"
        ],
        "in 1 day": [
            "эртеӊ"
        ],
        "in 1 month": [
            "эмдиги айда"
        ],
        "in 1 week": [
            "келерки апт",
            "келерки аптада"
        ],
        "in 1 year": [
            "эмдиги жылы"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "(\\d+) күн мурун"
        ],
        "\\1 hour ago": [
            "(\\d+) с мурн",
            "(\\d+) саат мурун"
        ],
        "\\1 minute ago": [
            "(\\d+) мүн мурн",
            "(\\d+) мүн мурун",
            "(\\d+) мүнөт мурун"
        ],
        "\\1 month ago": [
            "(\\d+) ай мурн",
            "(\\d+) ай мурун"
        ],
        "\\1 second ago": [
            "(\\d+) сек мурн",
            "(\\d+) сек мурун",
            "(\\d+) секунд мурун"
        ],
        "\\1 week ago": [
            "(\\d+) апт мурун",
            "(\\d+) апта мурун"
        ],
        "\\1 year ago": [
            "(\\d+) жыл мурун"
        ],
        "in \\1 day": [
            "(\\d+) күн кийин",
            "(\\d+) күндөн кийин"
        ],
        "in \\1 hour": [
            "(\\d+) с кийн",
            "(\\d+) саат кийин",
            "(\\d+) сааттан кийин"
        ],
        "in \\1 minute": [
            "(\\d+) мүн кийин",
            "(\\d+) мүн кийн",
            "(\\d+) мүнөттөн кийин"
        ],
        "in \\1 month": [
            "(\\d+) айд кийин",
            "(\\d+) айд кийн",
            "(\\d+) айдан кийин"
        ],
        "in \\1 second": [
            "(\\d+) сек кийин",
            "(\\d+) сек кийн",
            "(\\d+) секунддан кийин"
        ],
        "in \\1 week": [
            "(\\d+) апт кийин",
            "(\\d+) аптадан кийин"
        ],
        "in \\1 year": [
            "(\\d+) жыл кийин",
            "(\\d+) жылдан кийин"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
